summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorThorsten Behrens <thorsten.behrens@allotropia.de>2021-11-23 00:16:49 +0100
committerThorsten Behrens <thorsten.behrens@allotropia.de>2021-11-23 00:16:49 +0100
commit3a13a408113d09348039a2989f2a064c12134752 (patch)
tree72cac738bb7e09165c588fa172ed3e51decd700b
parentsymstore.sh: add vorbose mode (diff)
downloadcore-3a13a408113d09348039a2989f2a064c12134752.tar.gz
core-3a13a408113d09348039a2989f2a064c12134752.zip
replace usage of blacklist with denylist
.. and a few cases of instead doing blacklist->excludelist where that made more sense. Background and motivation: https://tools.ietf.org/html/draft-knodel-terminology-02 [API CHANGE] officecfg::Office::Canvas::DeviceBlacklist -> DeviceDenylist [API CHANGE] officecfg::Office::Canvas::BlacklistCurrentDevice -> DenylistCurrentDevice [API CHANGE] officecfg::Office::Common::Misc::OpenCLBlackList -> OpenCLDenyList Change-Id: Ia35e25496bf0cc0692d5de4cb66bfc232d3a869e Reviewed-on: https://gerrit.libreoffice.org/c/core/+/98180 Tested-by: Thorsten Behrens <Thorsten.Behrens@CIB.de> Reviewed-by: Thorsten Behrens <Thorsten.Behrens@CIB.de>
-rwxr-xr-xbin/symstore.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/bin/symstore.sh b/bin/symstore.sh
index 532efb16630f..c4e9870c9aa5 100755
--- a/bin/symstore.sh
+++ b/bin/symstore.sh
@@ -2,19 +2,19 @@
# Files listed here would not be store in the symbolestore-server.
# The format is a string with files e.g.
-# BLACKLIST="python.exe
+# EXCLUDE_LIST="python.exe
# file.dll
# next_file.exe"
#
# It removes "python.exe", "file.dll", and "next_file.exe" from what's
# added to the symstore. Separator is the newline
-BLACK_LIST="python.exe"
+EXCLUDE_LIST="python.exe"
# List files here where it's ok for this script to find more than one
# occurrence in the build tree. Files _not_ included here will generate
# an error, if duplicates are found.
#
# Same format as for BLACK_LIST above
MOREPDBS_OKLIST="libcurl.dll
freebl3.dll
libeay32.dll
@@ -46,7 +46,7 @@ add_pdb()
stats_morefound=0
declare -a pdball
echo "Collect $extension"
- ret=$(find "${INSTDIR}/" -type f -name "*.${extension}" | grep -vF "$BLACK_LIST")
+ ret=$(find "${INSTDIR}/" -type f -name "*.${extension}" | grep -vF "$EXCLUDE_LIST")
while IFS= read -r file
do
${VERBOSE} -n "Found: $file"
@@ -2,19 +2,19 @@
# an error, if duplicates are found.
#
-# Same format as for BLACK_LIST above
+# Same format as for EXCLUDE_LIST above
MOREPDBS_OKLIST="libcurl.dll
freebl3.dll